==> docfbe_2_2_32_56.zip: docfbe_2_2_32_56/source/TCFbECosineSimilarity.h <==
/*
    TCFbECosineSimilarity.h    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbECosineSimilarityH
#define TCFbECosineSimilarityH
//---------------------------------------------------------------------------
#include "TCFbESimilarityComputationAlgorithm.h"

class TCFbEDataSet;
#include "TCFbEDataSet.h"

#include "TCFbEToolkit.h"
#include <math.h>
//---------------------------------------------------------------------------
class TCFbECosineSimilarity : public TCFbESimilarityComputationAlgorithm
{
public:
    virtual __fastcall TCFbECosineSimilarity(void);    // RXgN^
    __fastcall ~TCFbECosineSimilarity();    // fXgN^

    virtual double __fastcall ComputeSimilarity(int TargetRowIndex, int ComparedRowIndex);    // TargetRowIndex  AnotherRowIndex ̗ގxvZ

protected:
    virtual double __fastcall GetValue(int RowIndex, int ColumnIndex);    // vẐ߂̒l擾

private:

};
//---------------------------------------------------------------------------
#endif

==> docfbe_2_2_34_61.zip: docfbe_2_2_34_61/source/TCFbECosineSimilarity.h <==
/*
    TCFbECosineSimilarity.h    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbECosineSimilarityH
#define TCFbECosineSimilarityH
//---------------------------------------------------------------------------
#include "TCFbESimilarityComputationAlgorithm.h"

class TCFbEDataSet;
#include "TCFbEDataSet.h"

#include "TCFbEToolkit.h"
#include <math.h>
//---------------------------------------------------------------------------
class TCFbECosineSimilarity : public TCFbESimilarityComputationAlgorithm
{
public:
    virtual __fastcall TCFbECosineSimilarity(void);    // RXgN^
    __fastcall ~TCFbECosineSimilarity();    // fXgN^

    virtual double __fastcall ComputeSimilarity(TCFbETable* SimilarityComputationTable, int TargetRowIndex, int ComparedRowIndex);    // TargetRowIndex  AnotherRowIndex ̗ގxvZ

protected:
    virtual double __fastcall GetValue(int RowIndex, int ColumnIndex);    // vẐ߂̒l擾

private:

};
//---------------------------------------------------------------------------
#endif
